pub fn parse_error_response(err: Error) -> JsonRpcResponseExpand description
Build the top-level parse-error response for a frame whose bytes could not be decoded as JSON.
pub fn parse_error_response(err: Error) -> JsonRpcResponseBuild the top-level parse-error response for a frame whose bytes could not be decoded as JSON.